Struct ThreadModeMutex
Source pub struct ThreadModeMutex<T: ?Sized> { }
A “mutex” that only allows borrowing from thread mode.
Safety
This Mutex is only safe on single-core systems.
On multi-core systems, a ThreadModeMutex is not sufficient to ensure exclusive access.
Lock the ThreadModeMutex, granting access to the data.
Panics
This will panic if not currently running in thread mode.
Borrows the data
Panics
This will panic if not currently running in thread mode.
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.